Standar Survey — Euphorie

# Bakeries

Download Print

## Risks that have been identified, evaluated and have an Action Plan

## 1 Physical work while baking

#### ⚠ 1.1 No attention is paid to avoid physical strengh unloading ovens

This is a low priority risk.

##### Measure 1

General approach (to eliminate or reduce the risk):
  When we buy or replace deck ovens we additional need occupational safety and health requirements, thus preventing workers developing disorders and the human/financial costs belonging to that.
Specific action(s) required to implement this approach:
  Ultricies amet ut cum! Turpis ridiculus? Placerat et! Quis magnis lectus enim eros enim, a proin elit eros placerat ac, elementum dis aliquam nascetur montes, amet auctor facilisis dapibus cras elementum magna et nec mauris elit.
Level of expertise and/or requirements needed:
  Knowledge of what kind of postures can lead to disorders with workers.

J Brand is responsible for this task which starts on August 4, 2011 and ends on August 8, 2011. There is a budget of € 6000 for this measure.

## Risks that have been identified but do NOT have an Action Plan

## 1 Physical work while baking

#### 1.2 Not manageable sack/drum weights are handled

This is a medium priority risk.

## Hazards/problems that have been "parked" and are still to be dealt with

The following risks have not yet been answered. Please do so at the soonest possibility.

## 2 Work with costumers

#### 2.1 Agreements are made when customers act agressive

This is a high priority risk.

## Hazards/problems that are not present in your organisation

## 2 Work with costumers

#### 2.2 These agreements are known to customers and workers

*) This risk is not present in your organisation, but since the sector organisation considers this one of the priority risks it must be included in this report.

1. Preparation
2. Identification
3. Evaluation
4. Action Plan
5. Report

- This report was based on the OiRA Tool 'Bakeries' of revision date March 29, 2011.

Produced by EU-OSHA. | About | Privacy | Disclaimer | GPL License |